Properties Methods Events Config Options Direct Link

# Class Ext.ux.DataViewTransition

Package: | Ext.ux
Defined In: | DataViewTransition.js
Class: | DataViewTransition
Extends: | Object

## Config Options

Config Options | Defined By
--- | ---
| enableTabbing : Boolean `true` to enable tabbing. Default is `false`. | DataViewTransition

## Public Properties

Property | Defined By
--- | ---
| cachedStoreData : Object A cache of existing store data, keyed by id. This is used to determine whether any items were added or removed from the store on data change | DataViewTransition
| dataview : Ext.DataView Reference to the DataView this instance is bound to | DataViewTransition
| dataviewID : String The string ID of the DataView component. This is used internally when animating child objects | DataViewTransition
| defaults : Object Default configuration options for all DataViewTransition instances | DataViewTransition

## Public Methods

Method | Defined By
--- | ---
| cacheStoreData( `Ext.data.Store store` ) : void Caches the records from a store locally for comparison later Caches the records from a store locally for comparison later Parameters: `store` : Ext.data.Store The store to cache data from Returns: void | DataViewTransition
| constructor( `Object config` ) : void Creates the plugin instance, applies defaults Creates the plugin instance, applies defaults Parameters: `config` : Object Optional config object Returns: void | DataViewTransition
| getAdded( `Ext.data.Store store` ) : Object Returns all records in the given store that were not already present Returns all records in the given store that were not already present Parameters: `store` : Ext.data.Store The updated store instance Returns: `Object` Object of records not already present in the dataview in format {id: record} | DataViewTransition
| getExisting() : Object Returns all records that were already in the DataView Returns all records that were already in the DataView Parameters: None. Returns: `Object` All existing records | DataViewTransition
| getExistingCount() : Number Returns the total number of items that are currently visible in the DataView Returns the total number of items that are currently visible in the DataView Parameters: None. Returns: `Number` The number of existing items | DataViewTransition
| getRemaining( `Ext.data.Store store` ) : Object Returns all records that are already present and are still present in the new store Returns all records that are already present and are still present in the new store Parameters: `store` : Ext.data.Store The updated store instance Returns: `Object` Object of records that are still present from last time in format {id: record} | DataViewTransition
| getRemoved( `Ext.data.Store store` ) : Array Returns all records that are present in the DataView but not the new store Returns all records that are present in the DataView but not the new store Parameters: `store` : Ext.data.Store The updated store instance Returns: `Array` Array of records that used to be present | DataViewTransition
| init( `Ext.DataView dataview` ) : void Initializes the transition plugin. Overrides the dataview's default refresh function Initializes the transition plugin. Overrides the dataview's default refresh function Parameters: `dataview` : Ext.DataView The dataview Returns: void | DataViewTransition

## Public Events

This class has no public events.